@@ -1,6 +1,6 @@
 package MetaStore::Response;
 
-#$Id: Response.pm 505 2009-03-03 19:24:18Z zag $
+#$Id: Response.pm 608 2009-09-14 17:30:24Z zag $
 
 use Data::Dumper;
 use WebDAO::Response;
@@ -34,6 +34,11 @@ sub json : lvalue {
     $self->{__json};
 }
 
+sub raw : lvalue {
+    my $self = shift;
+    $self->{__raw};
+}
+
 sub html : lvalue {
     my $self = shift;
     $self->{__html};
@@ -68,6 +73,7 @@ sub _destroy {
     $self->{__json} = undef;
     $self->{__html} = undef;
     $self->{__xml} = undef;
+    $self->{__raw}= undef; 
 #    $self->auto( [] );
 }
 1;
